<?php

//ini_set('display_errors', 1);
//ini_set('display_startup_errors', 1);
//error_reporting(E_ALL);

function readConfig($filename) {
    return parse_ini_file($filename, true);
}

// Function to write the configuration back to the ini file
function writeConfig($filename, $config) {
    $content = '';
    foreach ($config as $section => $values) {
        $content .= "[$section]\n";
        foreach ($values as $key => $value) {
            $content .= "$key=\"$value\"\n"; // Use quotes to preserve spaces
        }
        $content .= "\n";
    }
    file_put_contents($filename, $content);
}

// Define the path to your config file
$configFile = '/var/www/html/phproulette/config.ini';

// Read the current configuration
$config = readConfig($configFile);



$web_path = $config['web']['web_root_dir'];
$ws_host_url = $config['web']['ws_host_url'];

$public_path = str_replace('/var/www/html', '', $web_path);

// Database connection settings
$host = 'localhost';
$db = 'unity';
$user = 'root';
$password = 'T3mp0rary!';

// Create a new PDO instance
try {
    $pdo = new PDO("mysql:host=$host;dbname=$db;charset=utf8", $user, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Could not connect to the database: " . $e->getMessage());
}



// Handle user actions (add/edit/delete)
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST')
{
	 $message = "DEBUG: REQUEST_METHOD post detected";
	if (isset($_POST['user_action']))
	{
		
    $action = $_POST['user_action'];
    $username = $_POST['username'] ?? '';
    $user_password = $_POST['user_password'] ?? '';
    $user_email = $_POST['user_email'] ?? '';
    $user_balance = $_POST['user_balance'] ?? 0;
    $savelogin = isset($_POST['savelogin']) ? 'true' : 'false'; // Fix for remember me

    if ($action === 'add' && !empty($username) && !empty($user_password)) {
        // Add user to the database
        $stmt = $pdo->prepare("INSERT INTO users (username, password, email, balance, savelogin) VALUES (?, ?, ?, ?, ?)");
        $hashed_password = password_hash($user_password, PASSWORD_BCRYPT);
        $stmt->execute([$username, $hashed_password, $user_email, $user_balance, $savelogin]);
        $message = "User added successfully!";
    } elseif ($action === 'edit' && !empty($username)) {
        // Update user in the database
        $sql = "UPDATE users SET email = ?, balance = ?, savelogin = ?";
        $params = [$user_email, $user_balance, $savelogin];

        if (!empty($user_password)) {
            $hashed_password = password_hash($user_password, PASSWORD_BCRYPT);
            $sql .= ", password = ?";
            $params[] = $hashed_password;
        }

        $sql .= " WHERE username = ?";
        $params[] = $username;

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);

        $message = "User updated successfully!";
    } elseif ($action === 'delete' && !empty($username)) {
		try {
			// Delete user from the database
			$stmt = $pdo->prepare("DELETE FROM users WHERE username = ?");
			$stmt->execute([$username]);

			// Check if a row was actually deleted
			if ($stmt->rowCount() > 0) {
				$response = [
					'success' => true,
					'message' => 'User deleted successfully!'
				];
			} else {
				$response = [
					'success' => false,
					'message' => 'User not found or already deleted.'
				];
			}
		} catch (Exception $e) {
			// Handle any errors during deletion
			$response = [
				'success' => false,
				'message' => 'An error occurred: ' . $e->getMessage()
			];
		}

		// Return JSON response for the AJAX call
		echo json_encode($response);
		exit; // Ensure no further output is sent
	}


    // Return the updated user list
    if (isset($_POST['ajax'])) {
        $stmt = $pdo->query("SELECT username, email, balance, savelogin FROM users");
        $users = $stmt->fetchAll(PDO::FETCH_ASSOC);
        echo json_encode($users);
        exit;
    }
	}
	
	
	$response = [];

    if (isset($_POST['lobby_action'])) {

		
        $response['message'] = "DEBUG: lobby action detected";
        $action = $_POST['lobby_action'];


	if ($action === 'add') {
		$lobby_name = $_POST['name'] ?? '';
		$lobby_skin = $_POST['lobby_skin'] ?? '';
		$min_stake = $_POST['lobby_minstake'] ?? 0;
		$max_players = $_POST['edit_maxplayers'] ?? 0;
		$port = $_POST['lobby_port'] ?? '0';
		$countdown_time = $_POST['countdown_time'] ?? '0';
		$internal_timer = $_POST['internal_timer'] ?? '0';
		$anim1_time = $_POST['anim1_time'] ?? '0';
		$anim2_time = $_POST['anim2_time'] ?? '0';
		$anim3_time = $_POST['anim3_time'] ?? '0';

		// Handle the lobby creation logic
		if (isset($_POST['ajax'])) {
			try {
				// Insert the lobby into the database
				$stmt = $pdo->prepare("INSERT INTO lobbies (name, skin, min_stake, max_players, port, countdown_time, internal_timer, anim1_time, anim2_time, anim3_time) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
				$stmt->execute([$lobby_name, $lobby_skin, $min_stake, $max_players, $port, $countdown_time, $internal_timer, $anim1_time, $anim2_time, $anim3_time]);

				// Get the last inserted lobby ID
				$lobby_id = $pdo->lastInsertId();

				// Directory path for the new lobby
				$lobbyDir = "$web_path/$lobby_id/";

				// Create the lobby directory if it doesn't exist
				if (!is_dir($lobbyDir)) {
					if (mkdir($lobbyDir, 0755, true)) {
						//echo "Lobby directory created at $lobbyDir\n";

						// List of files to create with default content
						$files = [
							'anim1slowtrigger.txt' => '',
							'betsinplay.txt' => '',
							'clientscynced.txt' => '',
							'countdown.txt' => '60', // Default countdown value
							'global_anim1synced.txt' => '',
							'rl_animtrigger.txt' => '',
							'countdowntrigger.txt' => '',
							'debug_log.txt' => '',
							'internal_timer.txt' => $internal_timer, // Use the internal timer value
							'server_log.txt' => ''
						];

						// Create each file in the lobby directory
						foreach ($files as $filename => $content) {
							$filePath = $lobbyDir . $filename;
							file_put_contents($filePath, $content);
						}
						
						foreach ($files as $filename => $content) {
						$filePath = $lobbyDir . $filename;
						chown($filePath, 'www-data');
						chgrp($filePath, 'www-data');
						chmod($filePath, 0664); // Group can write, others can read
					}

						// Set directory and file permissions 
						chown($lobbyDir, 'www-data');
						chgrp($lobbyDir, 'www-data');
						
						// Set directory permissions to be writable by the group
						chmod($lobbyDir, 0775);
					} else {
						echo "Failed to create lobby directory.\n";
					}
				} else {
					echo "Lobby directory already exists.\n";
				}

				// Success response
				$response['success'] = true;
				$response['message'] = "Lobby added successfully!";
				
				// Return the list of lobbies
				$stmt2 = $pdo->query("SELECT * FROM lobbies");
				$lobbies = $stmt2->fetchAll(PDO::FETCH_ASSOC);
				$response['lobbies'] = $lobbies;
			} catch (PDOException $e) {
				// Error response
				$response['success'] = false;
				$response['message'] = "Error adding lobby: " . $e->getMessage();
			}

			// Return the response as JSON
			echo json_encode($response);
			exit;
		}
	}

		elseif ($action === 'edit') {
			$lobby_name = $_POST['name'] ?? '';
			$edit_name = $_POST['edit_name'];
			$lobby_skin = $_POST['edit_lobby_skin'] ?? '';
			$min_stake = $_POST['edit_minstake'] ?? 0;
			$max_players = $_POST['edit_maxplayers'] ?? 0;
			$port = $_POST['edit_port'] ?? '0';
			$countdown_time = $_POST['edit_countdown_time'] ?? '0';
			$internal_timer = $_POST['edit_internal_timer'] ?? '0';
			$anim1_time = $_POST['edit_anim1_time'] ?? '0';
			$anim2_time = $_POST['edit_anim2_time'] ?? '0';
			$anim3_time = $_POST['edit_anim3_time'] ?? '0';

			// New Color Fields
			$buttontxtcolor = $_POST['edit_buttontxtcolor'] ?? '#000000';
			$txtcolor = $_POST['edit_txtcolor'] ?? '#000000';
			$timercolor = $_POST['edit_timercolor'] ?? '#000000';
			$wn_redtxtcolor = $_POST['edit_wn_redtxtcolor'] ?? '#000000';
			$wn_blacktxtcolor = $_POST['edit_wn_blacktxtcolor'] ?? '#000000';
			$wn_zerotxtcolor = $_POST['edit_wn_zerotxtcolor'] ?? '#000000';

			try {
				$stmt = $pdo->prepare("UPDATE `lobbies` 
					SET `name` = ?, `skin` = ?, `min_stake` = ?, `max_players` = ?, `port` = ?, 
						`countdown_time` = ?, `internal_timer` = ?, `anim1_time` = ?, `anim2_time` = ?, 
						`anim3_time` = ?, `buttontxtcolor` = ?, `txtcolor` = ?, `timercolor` = ?, 
						`wn_redtxtcolor` = ?, `wn_blacktxtcolor` = ?, `wn_zerotxtcolor` = ? 
					WHERE `lobbies`.`name` = ?");

				$stmt->execute([$edit_name, $lobby_skin, $min_stake, $max_players, $port, 
								$countdown_time, $internal_timer, $anim1_time, $anim2_time, 
								$anim3_time, $buttontxtcolor, $txtcolor, $timercolor, 
								$wn_redtxtcolor, $wn_blacktxtcolor, $wn_zerotxtcolor, 
								$lobby_name]);

				$response['success'] = true;
				$response['message'] = "Lobby updated successfully!";
			} catch (PDOException $e) {
				$response['success'] = false;
				$response['message'] = "Error updating lobby: " . $e->getMessage();
			}

			echo json_encode($response);
			exit;
		}
		
		else if ($action === 'delete') {
		$lobby_name = $_POST['name'] ?? '';
		$lobby_id = $_POST['lobby_id'];
		
		// Prepare the SQL statement to delete the lobby
		$stmt = $pdo->prepare("DELETE FROM lobbies WHERE name = ?");

		// Get the directory path associated with the lobby
		$directoryPath = "$web_path/" . $lobby_id; // Modify this path as necessary

		// Execute the statement and check for success
		if ($stmt->execute([$lobby_name])) {
			// Attempt to delete the associated directory
			if (is_dir($directoryPath)) {
				// Use a recursive function to delete the directory and its contents
				function deleteDirectory($dir) {
					if (!is_dir($dir)) {
						return false;
					}
					// Scan the directory and delete files and subdirectories
					$items = scandir($dir);
					foreach ($items as $item) {
						if ($item == '.' || $item == '..') {
							continue; // Skip current and parent directory links
						}
						$path = $dir . DIRECTORY_SEPARATOR . $item;
						if (is_dir($path)) {
							// Recursively delete subdirectory
							deleteDirectory($path);
						} else {
							// Delete file
							unlink($path);
						}
					}
					// Remove the empty directory
					return rmdir($dir);
				}

				// Call the delete function
				if (!deleteDirectory($directoryPath)) {
					// Log or handle the error if the directory deletion fails
					error_log("Failed to delete directory: " . $directoryPath);
				}
			}

			// Return a JSON response on successful deletion
			echo json_encode([
				'success' => true,
				'message' => "Lobby and associated directory deleted successfully!"
			]);
		} else {
			// Return a JSON response on failure
			echo json_encode([
				'success' => false,
				'message' => "Failed to delete the lobby."
			]);
		}
		
		exit; // Exit to ensure no further output is sent
	}



		
    }
	
}

// Fetch all users from the database for display
$stmt = $pdo->query("SELECT username, email, balance, savelogin FROM users");
$users = $stmt->fetchAll(PDO::FETCH_ASSOC);



// Check if the form has been submitted
$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check the server_action value to confirm it's an 'edit' action
   if (isset($_POST['server_action']) && $_POST['server_action'] === 'edit') {
		// Debugging output (optional, you can remove this)
		// error_log("DEBUG: server cfg update code should run", 0); // This logs to error_log

		// Update the config array with the new values from the form
		$config['database']['db_host'] = $_POST['db_host'];
		$config['database']['db_user'] = $_POST['db_user'];
		$config['database']['db_password'] = $_POST['db_password'];
		$config['database']['db_name'] = $_POST['db_name'];
		$config['web']['web_host_url'] = $_POST['web_host_url'];
		$config['web']['chat_host_url'] = $_POST['chat_host_url'];
		$config['web']['ws_host_url'] = $_POST['ws_host_url'];

		// Write the updated configuration back to the ini file (or another storage)
		writeConfig($configFile, $config);

		// Create a new database connection to retrieve the install directory path from the system table
		$conn = new mysqli($_POST['db_host'], $_POST['db_user'], $_POST['db_password'], $_POST['db_name']);
		if ($conn->connect_error) {
			// If there is a connection error, return a failure message
			echo json_encode([
				'success' => false,
				'message' => "Database connection failed: " . $conn->connect_error
			]);
			exit();
		}

		// Fetch the install directory path from the system table
		$query = "SELECT installdir FROM `system` LIMIT 1";
		$result = $conn->query($query);
		if ($result && $row = $result->fetch_assoc()) {
			$installDir = $row['installdir'];

			// Modify the server.sh file with the values from the database
			$serverShPath = "$installDir/phproulette/server.sh";
			if (file_exists($serverShPath)) {
				// Read the existing server.sh content
				$serverShContent = file_get_contents($serverShPath);

				// Replace the placeholders in server.sh with the updated values
				$serverShContent = preg_replace('/DB_HOST=".*?"/', 'DB_HOST="' . $_POST['db_host'] . '"', $serverShContent);
				$serverShContent = preg_replace('/DB_USER=".*?"/', 'DB_USER="' . $_POST['db_user'] . '"', $serverShContent);
				$serverShContent = preg_replace('/DB_PASS=".*?"/', 'DB_PASS="' . $_POST['db_password'] . '"', $serverShContent);
				$serverShContent = preg_replace('/DB_NAME=".*?"/', 'DB_NAME="' . $_POST['db_name'] . '"', $serverShContent);

				// Write the modified content back to server.sh
				file_put_contents($serverShPath, $serverShContent);

				// Return a success message
				echo json_encode([
					'success' => true,
					'message' => "Configuration saved and server.sh updated successfully!"
				]);
			} else {
				// If server.sh is not found, return an error
				echo json_encode([
					'success' => false,
					'message' => "server.sh file not found at $installDir"
				]);
			}
		} else {
			// If install_dir is not found in the system table
			echo json_encode([
				'success' => false,
				'message' => "Error: 'install_dir' not found in the system table"
			]);
		}

		// Close the database connection
		$conn->close();

		// Stop further script execution
		exit();
	}
}



$stmt2 = $pdo->query("SELECT * FROM `lobbies`;");
$db_lobbies = $stmt2->fetchAll(PDO::FETCH_ASSOC);
//lobbies functions
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Configuration</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.2/dist/js/bootstrap.bundle.min.js"></script>
<link rel="stylesheet" href="jquery.minicolors.css">
<script src="jquery.minicolors.min.js"></script>
</head>
<style>
.custom-header {
    font-size: 0.7rem; /* Adjust the size as needed */
    font-weight: bold; /* Optional: makes the text bold */
}

 #terminal {
            width: 90ch; /* 80 characters wide */
            height: 590px; /* Fixed height */
            background-color: #000000; /* Terminal black background */
            border: 1px solid #333; /* Border around terminal */
            padding: 10px;
            overflow-y: auto; /* Enable vertical scrolling */
            white-space: pre-wrap; /* Preserve whitespace and line breaks */
            margin-top: 5px; /* Space between terminal and buttons */
	margin-bottom: 12px;		
	font-family: monospace;
			color: #ffffff;
	border-radius:10px;
        }

#launcher_btns
{
	margin-top: 12px;
}
.w-adjust
{
	width:50%;
}

.close-btn {
    background: none;
    border: none;
    color: #007bff; /* Bootstrap primary color */
    font-size: 1.5rem; /* Adjust size as needed */
    cursor: pointer;
    position: absolute; /* Position it to the right */
    right: 10px; /* Adjust spacing from the right */
    top: 5px; /* Adjust spacing from the top */
}
#messageDiv {
    overflow: hidden; /* Ensure content doesn't overflow when collapsed */
    max-height: 100px; /* Set a maximum height */
    transition: max-height 0.5s ease, opacity 0.5s ease; /* Transition for smooth effect */
    opacity: 1; /* Initial opacity */
}
</style>
<body>
    <div class="container mt-5">
        <center><img src="logo.png"></center>
        <h1>Admin Configuration</h1>
		<div id="messageDiv">
			<?php 
			if (!empty($message)) : 
				echo "Debug: Message is set."; 
			?>
				<div class="alert alert-success">
					<?php 
					$msg = htmlspecialchars($message);
					echo  "".$msg."";
					echo '<button class="close-btn" onclick="hideMessage()">×</button>'; ?>
				</div>
				<?php endif; ?>
		</div>

         <!-- Navigation Tabs -->
        <ul class="nav nav-tabs" id="myTab" role="tablist">
		<li class="nav-item">
                <a class="nav-link active" id="server-launcher-tab" data-toggle="tab" href="#server-launcher" role="tab" aria-controls="server-launcher" aria-selected="false">Server Launcher</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="server-config-tab" data-toggle="tab" href="#server-config" role="tab" aria-controls="server-config" aria-selected="false">Server Config</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="user-config-tab" data-toggle="tab" href="#user-config" role="tab" aria-controls="user-config" aria-selected="false">User Config</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="lobby-config-tab" data-toggle="tab" href="#lobby-config" role="tab" aria-controls="lobby-config" aria-selected="false">Lobby Config</a>
            </li>
        </ul>


        <div class="tab-content" id="myTabContent">
		<!-- Server Launcher Tab -->
		<div class="tab-pane fade show active" id="server-launcher" role="tabpanel" aria-labelledby="server-launcher-tab">
			<div id="launcher_btns">
				<button id="start" class="btn btn-primary">Start Server</button>
				<button id="stop" class="btn btn-danger">Stop Server</button>
				<button id="status" class="btn btn-warning">Check Status</button>
			</div>
			<div id="terminal"></div> <!-- Terminal output area -->

			<!-- Table for live lobby variables -->
			<div id="lobbyDataContainer">
				<h3>Lobby Variables</h3>
				<table id="lobbyTable" class="table">
					<thead>
						<tr>
							<th>Lobby ID</th>
							<th>Name</th>
							<th>global_anim1synced</th>
							<th>betsinplay</th>
							<th>countdown</th>
							<th>internal_timer</th>
							<th>clientscynced</th>
							<th>rl_animtrigger</th>
						</tr>
					</thead>
					<tbody>
						<?php
							// Assuming the database connection variables are set earlier in the script
							// $host, $user, $password, and $db should already be defined

							// Create connection
							$conn = new mysqli($host, $user, $password, $db);
							
							// Check connection
							if ($conn->connect_error) {
								die("Connection failed: " . $conn->connect_error);
							}

							// SQL query to get active lobbies (ID and Name)
							$sql = "SELECT id, name FROM `lobbies`"; // Replace with your actual table name
							$result = $conn->query($sql);

							if ($result->num_rows > 0) {
								while ($row = $result->fetch_assoc()) {
									echo "<tr id='lobby_{$row['id']}'>
											<td>{$row['id']}</td>
											<td>{$row['name']}</td>
											<td class='global_anim1synced'></td>
											<td class='betsinplay'></td>
											<td class='countdown'></td>
											<td class='internal_timer'></td>
											<td class='clientscynced'></td>
											<td class='rl_animtrigger'></td>
										  </tr>";
								}
							} else {
								echo "<tr><td colspan='11'>No active lobbies found.</td></tr>";
							}

							$conn->close();
						?>
					</tbody>
				</table>
			</div>
		</div>


		<!-- Server Config Tab -->
		<div class="tab-pane fade" id="server-config" role="tabpanel" aria-labelledby="server-config-tab">
            <form id="serverConfigForm" method="post" class="mt-3 w-adjust">
				<input type="hidden" name="server_action" value="edit"> <!-- Hidden input to specify action -->

				<h3>Database Configuration</h3>
				<div class="form-group">
					<label for="db_host">Database Host</label>
					<input type="text" class="form-control" id="db_host" name="db_host" value="<?php echo htmlspecialchars($config['database']['db_host']); ?>">
				</div>
				<div class="form-group">
					<label for="db_user">Database User</label>
					<input type="text" class="form-control" id="db_user" name="db_user" value="<?php echo htmlspecialchars($config['database']['db_user']); ?>">
				</div>
				<div class="form-group">
					<label for="db_password">Database Password</label>
					<input type="password" class="form-control" id="db_password" name="db_password" value="<?php echo htmlspecialchars($config['database']['db_password']); ?>">
				</div>
				<div class="form-group">
					<label for="db_name">Database Name</label>
					<input type="text" class="form-control" id="db_name" name="db_name" value="<?php echo htmlspecialchars($config['database']['db_name']); ?>">
				</div>

				<h3>Web Configuration</h3>
				<div class="form-group">
					<label for="web_host_url">Web Host URL</label>
					<input type="text" class="form-control" id="web_host_url" name="web_host_url" value="<?php echo htmlspecialchars($config['web']['web_host_url']); ?>">
				</div>
				<div class="form-group">
					<label for="chat_host_url">Chat Host URL</label>
					<input type="text" class="form-control" id="chat_host_url" name="chat_host_url" value="<?php echo htmlspecialchars($config['web']['chat_host_url']); ?>">
				</div>
				<div class="form-group">
					<label for="chat_host_url">Websocket Host URL</label>
					<input type="text" class="form-control" id="ws_host_url" name="ws_host_url" value="<?php echo htmlspecialchars($config['web']['ws_host_url']); ?>">
				</div>

				<!-- This will display the success or error messages -->

				<button type="submit" class="btn btn-primary">Save Changes</button>
			</form>

        </div>
			<!-- User Config Tab -->
            <div class="tab-pane fade" id="user-config" role="tabpanel" aria-labelledby="user-config-tab">
                <br>
		<h3>User Configuration</h3>
                <form id="addUserForm" method="post" class="mt-3 w-adjust">
                    <input type="hidden" name="user_action" value="add">
                    <div class="form-group">
                        <label for="username">Username</label>
                        <input type="text" class="form-control" id="username" name="username" required>
                    </div>
                    <div class="form-group">
                        <label for="user_password">Password</label>
                        <input type="password" class="form-control" id="user_password" name="user_password" required>
                    </div>
                    <div class="form-group">
                        <label for="user_email">Email</label>
                        <input type="email" class="form-control" id="user_email" name="user_email" required>
                    </div>
                    <div class="form-group">
                        <label for="user_balance">Balance</label>
                        <input type="number" class="form-control" id="user_balance" name="user_balance" required>
                    </div>
                    <div class="form-group form-check">
                        <input type="checkbox" class="form-check-input" id="savelogin" name="savelogin">
                        <label class="form-check-label" for="savelogin">Remember Me</label>
                    </div>
                    <button type="submit" class="btn btn-primary">Add User</button>
                </form>

                <h3 class="mt-5">Existing Users</h3>
                <table class="table table-bordered mt-3" id="userTable">
                    <thead>
                        <tr>
                            <th>Username</th>
                            <th>Email</th>
                            <th>Balance</th>
                            <th>Remember Me</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($users as $user): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($user['username']); ?></td>
                                <td><?php echo htmlspecialchars($user['email']); ?></td>
                                <td><?php echo htmlspecialchars($user['balance']); ?></td>
                                <td><?php echo htmlspecialchars($user['savelogin']); ?></td>
                                <td>
                                    <form method="post" class="d-inline deleteForm" data-tab="user-config">
                                        <input type="hidden" name="user_action" value="delete">
                                        <input type="hidden" name="username" value="<?php echo htmlspecialchars($user['username']); ?>">
                                        <button type="submit" class="btn btn-danger" style="float:right;">Delete</button>
                                    </form>
                                    <button class="btn btn-warning editBtn" data-toggle="modal" data-target="#editUserModal" 
                                        data-username="<?php echo htmlspecialchars($user['username']); ?>" 
                                        data-email="<?php echo htmlspecialchars($user['email']); ?>" 
                                        data-balance="<?php echo htmlspecialchars($user['balance']); ?>" 
                                        data-savelogin="<?php echo htmlspecialchars($user['savelogin']); ?>">Edit</button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
			<!-- Lobby Config Tab -->
			<div class="tab-pane fade" id="lobby-config" role="tabpanel" aria-labelledby="lobby-config-tab">
                <br>
			<h3>Add lobby</h3>
                <form id="addLobbyForm" method="post" class="mt-3 w-adjust">
                    <input type="hidden" name="lobby_action" value="add">
                    <div class="form-group">
                        <label for="name">Name</label>
                        <input type="text" class="form-control" id="name" name="name" required>
                    </div>
                    <div class="form-group">
                        <label for="lobby_skin">Skin</label>
                        <input type="text" class="form-control" id="lobby_skin" name="lobby_skin" required>
                    </div>
                    <div class="form-group">
                        <label for="lobby_port">Port</label>
                        <input type="text" class="form-control" id="lobby_port" name="lobby_port" required>
                    </div>
                    <div class="form-group">
                        <label for="lobby_minstake">Min. Stake</label>
                        <input type="text" class="form-control" id="lobby_minstake" name="lobby_minstake" required>
                    </div>
                    <button type="submit" class="btn btn-primary">Create Lobby</button>
                </form>

                <h3 class="mt-5">Existing Lobbies</h3>
                <table class="table table-bordered mt-3" id="lobbyTable">
                    <thead>
                        <tr>
                            <th class="custom-header">Name</th>
                            <th class="custom-header">Skin</th>
							<th class="custom-header">Port</th>
                            <th class="custom-header">Min. Stake</th>
							<th class="custom-header">Max. Players</th>
							<th class="custom-header">Countdown time</th>
							<th class="custom-header">Internal timer</th>
							<th class="custom-header">Anim1 time</th>
							<th class="custom-header">Anim2 time</th>
							<th class="custom-header">Anim3 time</th>
                            
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($db_lobbies as $lobbyarray): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($lobbyarray['name']); ?></td>
                                <td><?php echo htmlspecialchars($lobbyarray['skin']); ?></td>
                                <td><?php echo htmlspecialchars($lobbyarray['port']); ?></td>
                                <td><?php echo htmlspecialchars($lobbyarray['min_stake']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['max_players']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['countdown_time']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['internal_timer']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['anim1_time']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['anim2_time']); ?></td>
								<td><?php echo htmlspecialchars($lobbyarray['anim3_time']); ?></td>
                                <td>
                                    <form method="post" class="d-inline deleteLobbyForm">
										<input type="hidden" name="lobby_action" value="delete">
										<input type="hidden" name="lobby_id" value="<?php echo htmlspecialchars($lobbyarray['id']); ?>">
										<input type="hidden" name="name" value="<?php echo htmlspecialchars($lobbyarray['name']); ?>">
										<button type="submit" class="btn btn-danger" style="float:right;">Delete</button>
									</form>
									<!-- loading existing values into edit lobby modal -->
                                    <button class="btn btn-warning editBtn" data-toggle="modal" data-target="#editLobbyModal" 
										data-name="<?php echo htmlspecialchars($lobbyarray['name']); ?>" 
										data-skin="<?php echo htmlspecialchars($lobbyarray['skin']); ?>" 
										data-minstake="<?php echo htmlspecialchars($lobbyarray['min_stake']); ?>" 
										data-maxplayers="<?php echo htmlspecialchars($lobbyarray['max_players']); ?>"
										data-port="<?php echo htmlspecialchars($lobbyarray['port']); ?>" 
										data-countdowntime="<?php echo htmlspecialchars($lobbyarray['countdown_time']); ?>" 
										data-internaltimer="<?php echo htmlspecialchars($lobbyarray['internal_timer']); ?>" 
										data-anim1time="<?php echo htmlspecialchars($lobbyarray['anim1_time']); ?>" 
										data-anim2time="<?php echo htmlspecialchars($lobbyarray['anim2_time']); ?>" 
										data-anim3time="<?php echo htmlspecialchars($lobbyarray['anim3_time']); ?>" 
										data-buttontxtcolor="<?php echo htmlspecialchars($lobbyarray['buttontxtcolor']); ?>" 
										data-txtcolor="<?php echo htmlspecialchars($lobbyarray['txtcolor']); ?>" 
										data-timercolor="<?php echo htmlspecialchars($lobbyarray['timercolor']); ?>" 
										data-wn-redtxtcolor="<?php echo htmlspecialchars($lobbyarray['wn_redtxtcolor']); ?>" 
										data-wn-blacktxtcolor="<?php echo htmlspecialchars($lobbyarray['wn_blacktxtcolor']); ?>" 
										data-wn-zerotxtcolor="<?php echo htmlspecialchars($lobbyarray['wn_zerotxtcolor']); ?>">
										Edit
									</button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Edit User Modal -->
    <div class="modal fade" id="editUserModal" tabindex="-1" role="dialog" aria-labelledby="editUserModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editUserModalLabel">Edit User</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form id="editUserForm" method="post">
                    <div class="modal-body">
                        <input type="hidden" name="user_action" value="edit">
                        <div class="form-group">
                            <label for="edit_username">Username</label>
                            <input type="text" class="form-control" id="edit_username" name="username" readonly>
                        </div>
                        <div class="form-group">
                            <label for="edit_user_email">Email</label>
                            <input type="email" class="form-control" id="edit_user_email" name="user_email" required>
                        </div>
                        <div class="form-group">
                            <label for="edit_user_balance">Balance</label>
                            <input type="number" class="form-control" id="edit_user_balance" name="user_balance" required>
                        </div>
                        <div class="form-group">
                            <label for="edit_user_password">Password</label>
                            <input type="password" class="form-control" id="edit_user_password" name="user_password">
                        </div>
                        <div class="form-group form-check">
                            <input type="checkbox" class="form-check-input" id="edit_savelogin" name="savelogin">
                            <label class="form-check-label" for="edit_savelogin">Remember Me</label>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save Changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
	
	<!-- Edit Lobby Modal -->
    <div class="modal fade" id="editLobbyModal" tabindex="-1" role="dialog" aria-labelledby="editLobbyModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editLobbyModalLabel">Edit Lobby</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form id="editLobbyForm" method="post">
                    <div class="modal-body">
                        <input type="hidden" name="lobby_action" value="edit">
						 <input type="hidden" name="name" value="">
                        <div class="form-group">
                            <label for="edit_name">Name</label>
                            <input type="text" class="form-control" id="edit_name" name="edit_name">
                        </div>
                        <div class="form-group">
                            <label for="edit_lobby_skin">Skin</label>
                            <input type="text" class="form-control" id="edit_lobby_skin" name="edit_lobby_skin" >
                        </div>
                        <div class="form-group">
                            <label for="edit_minstake">Min. Stake</label>
                            <input type="number" class="form-control" id="edit_minstake" name="edit_minstake" >
                        </div>
                        <div class="form-group">
                            <label for="edit_maxplayers">Max. Players</label>
                            <input type="text" class="form-control" id="edit_maxplayers" name="edit_maxplayers">
                        </div>
						<div class="form-group">
                            <label for="edit_port">Port</label>
                            <input type="text" class="form-control" id="edit_port" name="edit_port">
                        </div>
						<div class="form-group">
                            <label for="edit_countdown_time">Countdown time</label>
                            <input type="text" class="form-control" id="edit_countdown_time" name="edit_countdown_time">
                        </div>
						<div class="form-group">
                            <label for="edit_internal_timer">Internal timer</label>
                            <input type="text" class="form-control" id="edit_internal_timer" name="edit_internal_timer">
                        </div>
						<div class="form-group">
                            <label for="edit_anim1_time">Anim1 time</label>
                            <input type="text" class="form-control" id="edit_anim1_time" name="edit_anim1_time">
                        </div>
						<div class="form-group">
                            <label for="edit_anim2_time">Anim 2 time</label>
                            <input type="text" class="form-control" id="edit_anim2_time" name="edit_anim2_time">
                        </div>
						<div class="form-group">
                            <label for="edit_anim3_time">Anim 3 time</label>
                            <input type="text" class="form-control" id="edit_anim3_time" name="edit_anim3_time">
                        </div>
						<div class="form-group">
							<label for="edit_buttontxtcolor">Button Text Color</label>
							<input type="text" class="form-control color-picker" id="edit_buttontxtcolor" name="edit_buttontxtcolor">
						</div>
						<div class="form-group">
							<label for="edit_txtcolor">Text Color</label>
							<input type="text" class="form-control color-picker" id="edit_txtcolor" name="edit_txtcolor">
						</div>
						<div class="form-group">
							<label for="edit_timercolor">Timer Color</label>
							<input type="text" class="form-control color-picker" id="edit_timercolor" name="edit_timercolor">
						</div>
						<div class="form-group">
							<label for="edit_wn_redtxtcolor">Win Red Text Color</label>
							<input type="text" class="form-control color-picker" id="edit_wn_redtxtcolor" name="edit_wn_redtxtcolor">
						</div>
						<div class="form-group">
							<label for="edit_wn_blacktxtcolor">Win Black Text Color</label>
							<input type="text" class="form-control color-picker" id="edit_wn_blacktxtcolor" name="edit_wn_blacktxtcolor">
						</div>
						<div class="form-group">
							<label for="edit_wn_zerotxtcolor">Win Zero Text Color</label>
							<input type="text" class="form-control color-picker" id="edit_wn_zerotxtcolor" name="edit_wn_zerotxtcolor">
						</div>

                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save Changes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
	
	$(document).ready(function () {
		// Initialize all color pickers
		$('.color-picker').minicolors({
			control: 'wheel',
			format: 'hex',
			theme: 'bootstrap'
		});
		
		$("#editLobbyForm").on("submit", function (e) {
        e.preventDefault(); // Prevent the default form submission

        // Send the form data via AJAX
        $.ajax({
            url: "admin.php", // Adjust this URL to the correct PHP script location
            method: "POST",
            data: $(this).serialize(), // Serialize the form data
            dataType: "json", // Expect a JSON response
            success: function (response) {
					if (response.success) {
						// Display success message
						alert(response.message);

						// Optionally close the modal
						$("#editLobbyModal").modal("hide");

						// Optionally reload or update the data on the page
						location.reload(); // Reload the page to reflect changes
					} else {
						// Display error message
						alert("Error: " + response.message);
					}
				},
				error: function (xhr, status, error) {
					// Handle AJAX errors
					console.error("AJAX Error:", status, error);
					alert("An error occurred while updating the lobby. Please try again.");
				},
			});
		});
	});
	
		//edit user modal 
        $('#editUserModal').on('show.bs.modal', function (event) {
		var button = $(event.relatedTarget);
		var username = button.data('username');
		var email = button.data('email');
		var balance = button.data('balance');
		var savelogin = button.data('savelogin') === true || button.data('savelogin') === 'true'; // Check both boolean and string

		var modal = $(this);
		modal.find('#edit_username').val(username);
		modal.find('#edit_user_email').val(email);
		modal.find('#edit_user_balance').val(balance);
		modal.find('#edit_savelogin').prop('checked', savelogin); // Set checkbox state based on database value
	});
	
	
		// Edit Lobby Modal
		$('#editLobbyModal').on('show.bs.modal', function (event) {
			var button = $(event.relatedTarget);

			// Existing data
			var name = button.data('name');
			var skin = button.data('skin');
			var minstake = button.data('minstake');
			var maxplayers = button.data('maxplayers');
			var port = button.data('port');
			var countdowntime = button.data('countdowntime');
			var internaltimer = button.data('internaltimer');
			var anim1time = button.data('anim1time');
			var anim2time = button.data('anim2time');
			var anim3time = button.data('anim3time');

			// New color data
			var buttontxtcolor = button.data('buttontxtcolor');
			var txtcolor = button.data('txtcolor');
			var timercolor = button.data('timercolor');
			var wnRedtxtcolor = button.data('wn-redtxtcolor');
			var wnBlacktxtcolor = button.data('wn-blacktxtcolor');
			var wnZerotxtcolor = button.data('wn-zerotxtcolor');

			// Populate modal fields
			var modal = $(this);

			// Existing fields
			modal.find('input[name="name"]').val(name);
			modal.find('#edit_name').val(name);
			modal.find('#edit_lobby_skin').val(skin);
			modal.find('#edit_minstake').val(minstake);
			modal.find('#edit_maxplayers').val(maxplayers);
			modal.find('#edit_port').val(port);
			modal.find('#edit_countdown_time').val(countdowntime);
			modal.find('#edit_internal_timer').val(internaltimer);
			modal.find('#edit_anim1_time').val(anim1time);
			modal.find('#edit_anim2_time').val(anim2time);
			modal.find('#edit_anim3_time').val(anim3time);

			// New color fields
			modal.find('#edit_buttontxtcolor').val(buttontxtcolor);
			modal.find('#edit_txtcolor').val(txtcolor);
			modal.find('#edit_timercolor').val(timercolor);
			modal.find('#edit_wn_redtxtcolor').val(wnRedtxtcolor);
			modal.find('#edit_wn_blacktxtcolor').val(wnBlacktxtcolor);
			modal.find('#edit_wn_zerotxtcolor').val(wnZerotxtcolor);
		});
	
	

        // Handle form submission for add/edit
        $('#addUserForm').on('submit', function (event) {
            event.preventDefault(); // Prevent the default form submission

            var form = $(this);
            $.ajax({
                type: form.attr('method'), // GET or POST
                url: form.attr('action'), // The form's action URL
                data: form.serialize() + '&ajax=true', // Serialize form data and include an ajax parameter
                success: function (response) {
                    if (response) {
                        // Update the user table with the new data
                        var users = JSON.parse(response);
                        var tbody = $('#userTable tbody');
                        tbody.empty(); // Clear existing table body

                        users.forEach(function(user) {
                            tbody.append(`
                                <tr>
                                    <td>${user.username}</td>
                                    <td>${user.email}</td>
                                    <td>${user.balance}</td>
                                    <td>${user.savelogin}</td>
                                    <td>
                                        <button class="btn btn-warning editBtn" data-toggle="modal" data-target="#editUserModal" 
                                            data-username="${user.username}" 
                                            data-email="${user.email}" 
                                            data-balance="${user.balance}" 
                                            data-savelogin="${user.savelogin}">Edit</button>
                                       <form method="post" class="d-inline deleteForm" data-tab="user-config">
                                            <input type="hidden" name="user_action" value="delete">
                                            <input type="hidden" name="username" value="${user.username}">
                                            <button type="submit" class="btn btn-danger"  style="float:right;">Delete</button>
                                        </form>
                                    </td>
                                </tr>
                            `);
                        });
                    }
                    // Close the modal if it's open
                    $('#editUserModal').modal('hide');
                    // Optionally show a success message
                    alert('User updated successfully!');
                }
            });
        });
		
	$('#addLobbyForm').on('submit', function (event) {
		event.preventDefault(); // Prevent the default form submission

		var form = $(this);
		$.ajax({
			type: form.attr('method'), // This will use POST
			url: form.attr('action'),
			data: form.serialize() + '&ajax=true',
			cache: false, // Prevent caching
			success: function (response) {
			console.log(response); // Log the raw response to see its contents
			if (response) {
				var result = JSON.parse(response);

				// Display the message if the lobby was added successfully
				if (result.success) {
					showMessage();
					$('#messageDiv').html(`<div class="alert alert-success">${result.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);

					// Wait for 2 seconds (2000 milliseconds) before scrolling
					setTimeout(function() {
						// Smooth scroll down to the bottom of the lobby table
						$('html, body').animate({
							scrollTop: $('#lobbyTable').offset().top + $('#lobbyTable').outerHeight() // Scroll to the bottom of the table
						}, 500); // Adjust the duration of the scroll as needed
					}, 1000); // Wait 1 second

					// Update the lobby table
					var tbody = $('#lobbyTable tbody');
					tbody.empty(); // Clear existing table body

					result.lobbies.forEach(function(lobby) {
						tbody.append(`
							<tr>
								<td>${lobby.name}</td>
								<td>${lobby.skin}</td>
								<td>${lobby.port}</td>
								<td>${lobby.min_stake}</td>
								<td>${lobby.max_players}</td>
								<td>${lobby.countdown_time}</td>
								<td>${lobby.internal_timer}</td>
								<td>${lobby.anim1_time}</td>
								<td>${lobby.anim2_time}</td>
								<td>${lobby.anim3_time}</td>
								<td>
									<form method="post" class="d-inline deleteForm">
										<input type="hidden" name="lobby_action" value="delete">
										<input type="hidden" name="name" value="${lobby.name}"> <!-- Modify if needed -->
										<input type="hidden" name="lobby_id" value="${lobby.id}">
										<button type="submit" class="btn btn-danger">Delete</button>
									</form>
									<button class="btn btn-warning editBtn" data-toggle="modal" data-target="#editLobbyModal" 
										data-name="${lobby.name}" 
										data-skin="${lobby.skin}" 
										data-minstake="${lobby.min_stake}" 
										data-maxplayers="${lobby.max_players}" 
										data-port="${lobby.port}" 
										data-countdowntime="${lobby.countdown_time}" 
										data-internaltimer="${lobby.internal_timer}" 
										data-anim1time="${lobby.anim1_time}" 
										data-anim2time="${lobby.anim2_time}" 
										data-anim3time="${lobby.anim3_time}">Edit</button>
								</td>
							</tr>
						`);
					});
				} else {
					showMessage();
					$('#messageDiv').html(`<div class="alert alert-danger">${result.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);
				}
			}
		},
			error: function (xhr, status, error) {
				console.error("Error adding lobby:", error);
			}
		});
	});
	
		// Add an event listener to each form with the class 'deleteForm'
		$(document).on('submit', '.deleteForm', function (event) {
		event.preventDefault(); // Prevent the default form submission

		var form = $(this); // Reference to the current form
		var tabId = form.data('tab'); // Get the tab ID from the data attribute

		// Save the active tab in localStorage
		localStorage.setItem('activeTab', tabId);

		// Display confirmation dialog before proceeding with the deletion
		if (confirm("Are you sure you want to delete this user? This action cannot be undone.")) {
			// User confirmed, proceed with AJAX request
			$.ajax({
				type: 'POST', // Ensure you are sending a POST request
				url: form.attr('action'), // The form action URL
				data: form.serialize(), // Serialize form data
				dataType: 'json', // Expecting JSON response
				success: function (response) {
					// Check if the deletion was successful
					if (response.success) {
						// Display a success message
						showMessage();
						$('#messageDiv').html(`<div class="alert alert-success">${response.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);

						// Remove the corresponding row from the table
						form.closest('tr').fadeOut(500, function () {
							$(this).remove(); // Fully remove the row after fading out
						});
					} else {
						// Display an error message if deletion was unsuccessful
						showMessage();
						$('#messageDiv').html(`<div class="alert alert-danger">${response.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);
					}
				},
				error: function (xhr, status, error) {
					console.error("Error deleting user:", error);
					showMessage();
					$('#messageDiv').html('<div class="alert alert-danger">An error occurred during deletion.</div><button class="close-btn" onclick="hideMessage()">×</button>');
				}
			});
		} else {
			// User canceled the deletion
			alert("User deletion canceled.");
		}
	});



	// On page load, check localStorage and activate the tab
	$(document).ready(function () {
		// Activate the saved tab on page load
		var activeTab = localStorage.getItem('activeTab');
		if (activeTab) {
			// Hide all tab content and deactivate all tabs
			$('.tab-content .tab-pane').hide(); // Hide initially
			$('.nav-tabs a').removeClass('active');

			// Set the saved tab as active and fade it in
			$(`#${activeTab}-tab`).addClass('active');
			$(`#${activeTab}`).fadeIn(200).addClass('show active'); // Fade in the active tab
		}

		// Save the active tab when clicked
		$('.nav-tabs a').on('click', function () {
			var tabId = $(this).attr('id').replace('-tab', ''); 
			localStorage.setItem('activeTab', tabId);
			
			// Hide all tab content and deactivate all tabs
			$('.tab-content .tab-pane').removeClass('show active').fadeOut(200); // Fade out
			$('.nav-tabs a').removeClass('active');

			// Activate the clicked tab
			$(this).addClass('active');
			$(`#${tabId}`).fadeIn(200).addClass('show active'); // Fade in the new active tab
		});
	});


	
	$('#serverConfigForm').on('submit', function (event) {
		event.preventDefault(); // Prevent the default form submission

		var form = $(this); // Reference to the current form

		$.ajax({
			type: form.attr('method'), // This will use POST
			url: form.attr('action'), // Set the URL where the form will be submitted
			data: form.serialize(), // Serialize form data
			cache: false, // Prevent caching
			success: function (response) {
				var result = JSON.parse(response);

				// If the form submission was successful
				if (result.success) {
					showMessage();
					$('#messageDiv').html(`<div class="alert alert-success">${result.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);

					// Smooth scroll to the messageDiv to ensure the message is visible
					$('html, body').animate({
						scrollTop: $('#messageDiv').offset().top
					}, 500); // Adjust scroll duration if needed
				} else {
					// Display an error message
					showMessage();
					$('#messageDiv').html(`<div class="alert alert-danger">${result.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);

					// Optionally, scroll to the messageDiv for error visibility
					$('html, body').animate({
						scrollTop: $('#messageDiv').offset().top
					}, 500); // Adjust scroll duration if needed
				}
			},
			error: function (xhr, status, error) {
				// Display error message if something goes wrong with the AJAX call
				showMessage();
				$('#messageDiv').html(`<div class="alert alert-danger">An error occurred: ${error}<button class="close-btn" onclick="hideMessage()">×</button></div>`);

				// Smooth scroll to the messageDiv to ensure the error is visible
				$('html, body').animate({
					scrollTop: $('#messageDiv').offset().top
				}, 500); // Adjust scroll duration if needed
			}
		});
	});

	$('.deleteLobbyForm').on('submit', function (event) {
		event.preventDefault(); // Prevent the default form submission

		var form = $(this); // Reference to the current form

		// Display confirmation dialog before proceeding with the deletion
		if (confirm("Are you sure you want to delete this lobby? This action cannot be undone.")) {
			// User confirmed, proceed with AJAX request
			$.ajax({
				type: form.attr('method'), // This will use POST
				url: form.attr('action'), // Set the URL where the form will be submitted
				data: form.serialize(), // Serialize form data
				cache: false, // Prevent caching
				success: function (response) {
					var result = JSON.parse(response);

					// Check if the deletion was successful
					if (result.success) {
						// Optionally display a success message
						showMessage();
						$('#messageDiv').html(`<div class="alert alert-success">${result.message}</div><button class="close-btn" onclick="hideMessage()">×</button>`);

						// Remove the corresponding row from the table
						form.closest('tr').remove();

						// Optionally scroll to the top of the table after deletion
						$('html, body').animate({
							scrollTop: $('#lobbyTable').offset().top // Scroll to the top of the table
						}, 500); // Adjust the duration of the scroll if needed

					} else {
						// Display an error message if deletion was unsuccessful
						showMessage();
						$('#messageDiv').html(`<div class="alert alert-danger">${result.message}<button class="close-btn" onclick="hideMessage()">×</button></div>`);
					}
				},
				error: function (xhr, status, error) {
					// Display error message if something goes wrong with the AJAX call
					showMessage();
					$('#messageDiv').html(`<div class="alert alert-danger">An error occurred: ${error}<button class="close-btn" onclick="hideMessage()">×</button></div>`);
				}
			});
		} else {
			// User canceled the deletion
			alert("Lobby deletion canceled.");
		}
	});



    </script>
	
<script>
        const terminal = document.getElementById('terminal');
        let ws;
        const reconnectInterval = 5000; // Time (in ms) to wait before attempting to reconnect

        // Function to create WebSocket connection
        function connectWebSocket() {
            var ws_host_url = "<?php echo $ws_host_url; ?>"; // Echo the PHP variable
			console.log("WebSocket URL: ", ws_host_url); // Check the URL
			ws = new WebSocket(ws_host_url); // Use the PHP variable

            ws.onopen = () => {
                appendToTerminal("Connected to WebSocket server.");
				//handleServerMessage(event.data);
            };

            ws.onmessage = (event) => {
                handleServerMessage(event.data);
            };

            ws.onerror = (error) => {
                appendToTerminal("WebSocket error: " + error.message);
            };

            ws.onclose = () => {
                appendToTerminal("WebSocket connection closed. Attempting to reconnect...");
                setTimeout(connectWebSocket, reconnectInterval); // Attempt to reconnect
            };
        }

        // Initial WebSocket connection
        connectWebSocket();

        document.getElementById('start').onclick = () => {
            appendToTerminal("Sending start command...");
            ws.send('start_server');
        };

        document.getElementById('stop').onclick = () => {
            appendToTerminal("Sending stop command...");
            ws.send('stop_server');
        };

        document.getElementById('status').onclick = () => {
            appendToTerminal("Sending check status command...");
            ws.send('check_status');
        };

        // Function to append text to the terminal
        function appendToTerminal(text) {
            terminal.innerHTML += text + '\n'; // Append the text and add a new line
            terminal.scrollTop = terminal.scrollHeight; // Auto-scroll to the bottom
        }

        // Function to handle server messages and clear terminal if needed
        function handleServerMessage(message) {
            // Check for escape sequences for clearing
            if (message.includes('\x1b[H') || message.includes('\x1b[2J') || message.includes('\x1b[3J')) {
                clearTerminal();
            } else {
                appendToTerminal(message);
            }
        }

        // Function to clear the terminal
        function clearTerminal() {
            terminal.innerHTML = ''; // Clear terminal content
        }
    </script>

	
	<script>
	//close message animation
		function hideMessage() {
		const messageDiv = document.getElementById('messageDiv');
		messageDiv.style.transition = 'max-height 0.5s ease, opacity 0.5s ease'; // For smooth transition
		messageDiv.style.maxHeight = '0'; // Collapse the div
		messageDiv.style.opacity = '0'; // Fade out effect

		setTimeout(() => {
			messageDiv.style.display = 'none'; // Remove from display after transition
		}, 500); // Match this duration with the CSS transition duration
		}
		
		function showMessage() {
			const messageDiv = document.getElementById('messageDiv');
			messageDiv.style.display = 'block'; // Make the div visible again
			setTimeout(() => {
				messageDiv.style.maxHeight = '100px'; // Adjust as per the actual content height
				messageDiv.style.opacity = '1'; // Fade back in
			}, 10); // Small delay to ensure transitions apply correctly
		}
	</script>
	
<script>
$(document).ready(function() {
    function updateLobbyData() {
        $("tr[id^='lobby_']").each(function() {
            const $row = $(this);
            const lobbyId = $row.attr("id").split("_")[1];
            const files = [
                "global_anim1synced.txt",
                "betsinplay.txt",
                "countdown.txt",
                "internal_timer.txt",
                "clientscynced.txt",
                "rl_animtrigger.txt"
            ];

            files.forEach(file => {
                const cacheBuster = new Date().getTime(); // Disable cache by adding a unique parameter
                 $.get(`<?php echo  $config['web']['web_host_url']; ?>/${lobbyId}/${file}?_=${cacheBuster}`, function(data) {
                    const $cell = $row.find(`.${file.split('.')[0]}`);
                    
                    // Only update the cell if the content has changed to avoid unnecessary reflows
                    if ($cell.text() !== data) {
                        $cell.text(data);
                    }
                }).fail(function() {
                    $row.find(`.${file.split('.')[0]}`).text("Error loading");
                });
            });
        });
    }

    // Use 1-second updates for near real-time updates
    setInterval(updateLobbyData, 1000); // Update every 1 second
});
</script>








</body>
</html>
