<?php
require __DIR__ . '/vendor/autoload.php'; // Ensure Composer's autoload is included

use WebSocket\Client;

$config = parse_ini_file('config.ini', true);

$servername = $config['database']['db_host'];
$DbUsername = $config['database']['db_user'];
$DbPassword = $config['database']['db_password'];
$dbname = $config['database']['db_name'];

// Get lobby_id from command line arguments
$lobby_id = $argv[1] ?? '';

// Validate lobby_id
if (empty($lobby_id)) {
    error_log("No lobby_id provided.", 3, __DIR__ . "/debug.log");
    die("1"); // 1 = invalid lobby_id
}

// Create connection to the database
$conn = new mysqli($servername, $DbUsername, $DbPassword, $dbname);

// Check connection
if ($conn->connect_error) {
    error_log("Connection failed: " . $conn->connect_error, 3, __DIR__ . "/debug.log");
    die("1"); // 1 = connection failed
}

// Query to delete entries from bets_inplay where lobby matches $lobby_id
$sql = "DELETE FROM bets_inplay WHERE lobby = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $lobby_id);

if ($stmt->execute()) {
    echo "Records deleted successfully from bets_inplay.";
} else {
    error_log("Error deleting records from bets_inplay: " . $stmt->error, 3, __DIR__ . "/debug.log");
    echo "Error deleting records from bets_inplay.";
}

$stmt->close();

// Query to delete entries from animationsync where lobbyid matches $lobby_id
$sql = "DELETE FROM animationsync WHERE lobbyid = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $lobby_id);

if ($stmt->execute()) {
    echo "Records deleted successfully from animationsync.";
} else {
    error_log("Error deleting records from animationsync: " . $stmt->error, 3, __DIR__ . "/debug.log");
    echo "Error deleting records from animationsync.";
}

$stmt->close();

// Query to get the port for the WebSocket server based on lobby_id
$sql = "SELECT port FROM lobbies WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $lobby_id);
$stmt->execute();
$stmt->bind_result($port);
$stmt->fetch();
$stmt->close();
$conn->close();

// Validate port
if (empty($port)) {
    error_log("No port found for lobby_id: $lobby_id.", 3, __DIR__ . "/debug.log");
    die("1"); // 1 = invalid port
}

// Define WebSocket server URL
$websocketurl = $config['web']['chat_host_url'];
$wsServerUrl = "$websocketurl:$port";

// Send trigger message to the WebSocket server using the WebSocket client
try {
    $client = new Client($wsServerUrl);
    $updateMessage = "UPDATE_LOBBY:$lobby_id";
    $client->send($updateMessage);

    // Optionally, you can receive a response from the WebSocket server
    //$response = $client->receive();
    
    // Optional: Log the response from the WebSocket server for debugging
    error_log("Trigger message response: $response", 3, __DIR__ . "/debug.log");
} catch (Exception $e) {
    error_log("WebSocket error: " . $e->getMessage(), 3, __DIR__ . "/debug.log");
    die("1"); // 1 = WebSocket error
}
?>
