<?php
// Database connection
$config = parse_ini_file('config.ini', true);

$servername = $config['database']['db_host'];
$DbUsername = $config['database']['db_user'];
$DbPassword = $config['database']['db_password'];
$dbname = $config['database']['db_name'];

// Get lobby_id from command line or external parameter
if ($argc < 2) {
    error_log("No lobby_id provided.", 3, __DIR__ . "/debug.log");
    die("No lobby_id provided.");
}

$lobby_id = $argv[1];  // Get lobby_id from command-line argument

$conn = new mysqli($servername, $DbUsername, $DbPassword, $dbname);

// Check connection
if ($conn->connect_error) {
    error_log("Connection failed: " . $conn->connect_error, 3, __DIR__ . "/debug.log");
    die("Connection failed: " . $conn->connect_error);
}

// Retrieve the last winning number from numberhistory for this lobby
$sql = "SELECT number FROM numberhistory WHERE lobby = ? ORDER BY timestamp DESC LIMIT 1";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $lobby_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $winning_number = intval($row['number']);
} else {
    die("No winning number found in history for lobby $lobby_id.");
}

$color = getColor($winning_number);

// Query to get all bets in play for the current lobby
$sql = "SELECT * FROM bets_inplay WHERE lobby = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $lobby_id);
$stmt->execute();
$result = $stmt->get_result();

$column_mapping = [
    1 => 'one', 2 => 'two', 3 => 'three', 4 => 'four', 5 => 'five', 6 => 'six',
    7 => 'seven', 8 => 'eight', 9 => 'nine', 10 => 'ten', 11 => 'eleven', 12 => 'twelve',
    13 => 'thirteen', 14 => 'fourteen', 15 => 'fifteen', 16 => 'sixteen', 17 => 'seventeen',
    18 => 'eighteen', 19 => 'nineteen', 20 => 'twenty', 21 => 'twentyone', 22 => 'twentytwo',
    23 => 'twentythree', 24 => 'twentyfour', 25 => 'twentyfive', 26 => 'twentysix',
    27 => 'twentyseven', 28 => 'twentyeight', 29 => 'twentynine', 30 => 'thirty',
    31 => 'thirtyone', 32 => 'thirtytwo', 33 => 'thirtythree', 34 => 'thirtyfour',
    35 => 'thirtyfive', 36 => 'thirtysix'
];

// Array to hold total winnings for each user
$user_winnings = [];

if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $username = $row['username'];
        $total_winnings = 0;

        // Check individual number bets (1-36) using column_mapping
        foreach ($column_mapping as $number => $column_name) {
            $bet_amount = intval($row[$column_name]);
            if ($bet_amount > 0 && $winning_number == $number) {
                $total_winnings += $bet_amount * 35; // Straight-up bet pays 35:1
            }
        }

        // Check for zero bet
        $bet_amount = intval($row['zero']);
        if ($bet_amount > 0 && $winning_number == 0) {
            $total_winnings += $bet_amount * 35;
        }

        // Check for color bets
        if ($winning_number != 0) {
            if ($row['red'] > 0 && $color === 'red') {
                $total_winnings += intval($row['red']) * 2;
            } elseif ($row['black'] > 0 && $color === 'black') {
                $total_winnings += intval($row['black']) * 2;
            }
        }

        // Check for even/odd bets
        if ($winning_number != 0) {
            if ($row['even'] > 0 && $winning_number % 2 == 0) {
                $total_winnings += intval($row['even']) * 2;
            } elseif ($row['odd'] > 0 && $winning_number % 2 != 0) {
                $total_winnings += intval($row['odd']) * 2;
            }
        }

        // Check for 1-18 / 19-36 bets
        if ($row['1to18'] > 0 && $winning_number >= 1 && $winning_number <= 18) {
            $total_winnings += intval($row['1to18']) * 2;
        } elseif ($row['19to36'] > 0 && $winning_number >= 19 && $winning_number <= 36) {
            $total_winnings += intval($row['19to36']) * 2;
        }

        // Check for 2-to-1 column bets
        $column = getColumn($winning_number);
        if ($row['2to1_left'] > 0 && $column === 'left') {
            $total_winnings += intval($row['2to1_left']) * 3;
        } elseif ($row['2to1_middle'] > 0 && $column === 'middle') {
            $total_winnings += intval($row['2to1_middle']) * 3;
        } elseif ($row['2to1_right'] > 0 && $column === 'right') {
            $total_winnings += intval($row['2to1_right']) * 3;
        }

        // Check for 1st, 2nd, 3rd third (dozens) bets
        if ($row['1st_third'] > 0 && $winning_number >= 1 && $winning_number <= 12) {
            $total_winnings += intval($row['1st_third']) * 3;
        } elseif ($row['2nd_third'] > 0 && $winning_number >= 13 && $winning_number <= 24) {
            $total_winnings += intval($row['2nd_third']) * 3;
        } elseif ($row['3rd_third'] > 0 && $winning_number >= 25 && $winning_number <= 36) {
            $total_winnings += intval($row['3rd_third']) * 3;
        }

        // Check for square bets
        $squares = getSquaresForNumber($winning_number);
        foreach ($squares as $square) {
            if (intval($row[$square]) > 0) {
                $total_winnings += intval($row[$square]) * 9;
            }
        }

        // Check for street bets
        $streets = getStreetsForNumber($winning_number);
        foreach ($streets as $street) {
            if (intval($row[$street]) > 0) {
                $total_winnings += intval($row[$street]) * 12;
            }
        }

        // Check for sixline bets
        $sixlines = getSixLinesForNumber($winning_number);
        foreach ($sixlines as $sixline) {
            if (intval($row[$sixline]) > 0) {
                $total_winnings += intval($row[$sixline]) * 6;
            }
        }

        // Store total winnings for this user
        if ($total_winnings > 0) {
            if (!isset($user_winnings[$username])) {
                $user_winnings[$username] = 0;
            }
            $user_winnings[$username] += $total_winnings;
        }
    }

    // Insert total winnings into `wins` table for the current lobby
    foreach ($user_winnings as $username => $total_winnings) {
        $timestamp = date('Y-m-d H:i:s');
        $sql_insert_wins = "INSERT INTO `wins` (`username`, `timestamp`, `amount`, `lobby`) VALUES (?, ?, ?, ?)";
        $stmt_insert = $conn->prepare($sql_insert_wins);
        $stmt_insert->bind_param("ssii", $username, $timestamp, $total_winnings, $lobby_id);

        if ($stmt_insert->execute()) {
            // Update user balance in users table
            $sql_update_balance = "UPDATE users SET balance = balance + ? WHERE username = ?";
            $stmt_update = $conn->prepare($sql_update_balance);
            $stmt_update->bind_param("is", $total_winnings, $username);
            if ($stmt_update->execute()) {
                // Get the updated balance to display
                $new_balance = $stmt_update->affected_rows ? $conn->query("SELECT balance FROM users WHERE username = '$username'")->fetch_assoc()['balance'] : null;
                if ($new_balance !== null) {
                    echo "Player $username won a total of $total_winnings in lobby $lobby_id.\n";
                    echo "Updated balance for user $username to $new_balance.\n";
                } else {
                    error_log("Failed to retrieve updated balance for user $username.", 3, __DIR__ . "/debug.log");
                }
            } else {
                error_log("Failed to update balance for user $username: " . $stmt_update->error, 3, __DIR__ . "/debug.log");
            }
        } else {
            error_log("Failed to log winnings for user $username: " . $stmt_insert->error, 3, __DIR__ . "/debug.log");
        }
    }
} else {
    error_log("No bets found for lobby $lobby_id.", 3, __DIR__ . "/debug.log");
}

$stmt->close();
$conn->close();

function getColor($number) {
    // Implement logic to determine color based on number
    if ($number == 0) return 'green';
    return in_array($number, [1, 3, 5, 7, 9, 12, 14, 16, 18, 19, 21, 23, 25, 27, 30, 32, 34]) ? 'red' : 'black';
}

function getColumn($number) {
    // Implement logic to determine the column based on number
    if ($number === 0) return 'none'; // Or handle as you see fit
    return ($number % 3 === 1) ? 'left' : (($number % 3 === 2) ? 'middle' : 'right');
}

function getSquaresForNumber($number) {
    // Implement logic to return squares based on the number
    return []; // Return an empty array if no squares found
}

function getStreetsForNumber($number) {
    // Implement logic to return streets based on the number
    return []; // Return an empty array if no streets found
}

function getSixLinesForNumber($number) {
    // Implement logic to return sixlines based on the number
    return []; // Return an empty array if no sixlines found
}
?>
